pycocoa.oslibs.OSlibError

Package pycocoa :: Module oslibs :: Class OSlibError |
[frames] | no frames]

# Class OSlibError

                  object --+
                           |
    exceptions.BaseException --+
                               |
            exceptions.Exception --+
                                   |
            exceptions.StandardError --+
                                       |
             exceptions.EnvironmentError --+
                                           |
                          exceptions.OSError --+
                                               |
                                              OSlibError

Couldn't find or load a macOS `.dylib` library.

Instance Methods
__init__(self, verb, name, *ns) x.__init__(...) initializes x; see help(type(x)) for signature |
Inherited from `exceptions.OSError`: `__new__` Inherited from `exceptions.EnvironmentError`: `__reduce__`, `__str__` Inherited from `exceptions.BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__repr__`, `__setattr__`, `__setstate__`, `__unicode__` Inherited from `object`: `__format__`, `__hash__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `exceptions.EnvironmentError`: `errno`, `filename`, `strerror` Inherited from `exceptions.BaseException`: `args`, `message` Inherited from `object`: `__class__`

Method Details

### __init__(self, verb, name, *ns) (Constructor) |
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)